==> parcel-bundler-vue-1.6.3.tgz: package/lib/assets/CoffeeScriptAsset.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var JSAsset = require('./JSAsset');
var localRequire = require('../utils/localRequire');

var CoffeeScriptAsset = function (_JSAsset) {
  (0, _inherits3.default)(CoffeeScriptAsset, _JSAsset);

  function CoffeeScriptAsset() {
    (0, _classCallCheck3.default)(this, CoffeeScriptAsset);
    return (0, _possibleConstructorReturn3.default)(this, (CoffeeScriptAsset.__proto__ || (0, _getPrototypeOf2.default)(CoffeeScriptAsset)).apply(this, arguments));
  }

  (0, _createClass3.default)(CoffeeScriptAsset, [{
    key: 'install',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.t0 = [];
                _context.t1 = _toConsumableArray3.default;
                _context.next = 4;
                return (0, _get3.default)(CoffeeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(CoffeeScriptAsset.prototype), 'install', this).call(this);

              case 4:
                _context.t2 = _context.sent;
                _context.t3 = (0, _context.t1)(_context.t2);
                _context.t4 = [{ name: 'coffeescript', dev: true }];
                return _context.abrupt('return', _context.t0.concat.call(_context.t0, _context.t3, _context.t4));

              case 8:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function install() {
        return _ref.apply(this, arguments);
      }

      return install;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var coffee, transpiled;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return localRequire('coffeescript', this.name);

              case 2:
                coffee = _context2.sent;


                // Transpile Module using CoffeeScript and parse result as ast format through babylon
                transpiled = coffee.compile(code, {
                  sourceMap: this.options.sourceMaps
                });


                if (transpiled.sourceMap) {
                  this.sourceMap = transpiled.sourceMap.generate();
                  this.sourceMap.sources = [this.relativeName];
                  this.sourceMap.sourcesContent = [this.contents];
                }

                this.contents = this.options.sourceMaps ? transpiled.js : transpiled;
                _context2.next = 8;
                return (0, _get3.default)(CoffeeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(CoffeeScriptAsset.prototype), 'parse', this).call(this, this.contents);

              case 8:
                return _context2.abrupt('return', _context2.sent);

              case 9:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }]);
  return CoffeeScriptAsset;
}(JSAsset);

module.exports = CoffeeScriptAsset;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/assets/CoffeeScriptAsset.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var JSAsset = require('./JSAsset');
var localRequire = require('../utils/localRequire');

var CoffeeScriptAsset = function (_JSAsset) {
  (0, _inherits3.default)(CoffeeScriptAsset, _JSAsset);

  function CoffeeScriptAsset() {
    (0, _classCallCheck3.default)(this, CoffeeScriptAsset);
    return (0, _possibleConstructorReturn3.default)(this, (CoffeeScriptAsset.__proto__ || (0, _getPrototypeOf2.default)(CoffeeScriptAsset)).apply(this, arguments));
  }

  (0, _createClass3.default)(CoffeeScriptAsset, [{
    key: 'install',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.t0 = [];
                _context.t1 = _toConsumableArray3.default;
                _context.next = 4;
                return (0, _get3.default)(CoffeeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(CoffeeScriptAsset.prototype), 'install', this).call(this);

              case 4:
                _context.t2 = _context.sent;
                _context.t3 = (0, _context.t1)(_context.t2);
                _context.t4 = [{ name: 'coffeescript', dev: true }];
                return _context.abrupt('return', _context.t0.concat.call(_context.t0, _context.t3, _context.t4));

              case 8:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function install() {
        return _ref.apply(this, arguments);
      }

      return install;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var coffee;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return localRequire('coffeescript', this.name);

              case 2:
                coffee = _context2.sent;


                // Transpile Module using CoffeeScript and parse result as ast format through babylon
                this.contents = coffee.compile(code, {});
                _context2.next = 6;
                return (0, _get3.default)(CoffeeScriptAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(CoffeeScriptAsset.prototype), 'parse', this).call(this, this.contents);

              case 6:
                return _context2.abrupt('return', _context2.sent);

              case 7:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }]);
  return CoffeeScriptAsset;
}(JSAsset);

module.exports = CoffeeScriptAsset;
